==> zzyj-financeintegration-api-3.0.0-20241203.015238-98-sources.jar: com/ejianc/business/financeintegration/PMSalary/vo/PMGzDetailVO.java <==
package com.ejianc.business.financeintegration.PMSalary.vo;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;

import java.math.BigDecimal;


@TableName("PMSALARY_GZMX")
public class PMGzDetailVO {

    private static final long serialVersionUID = 1L;
    /**
     * 项目ID
     */
    private String id;

    /**
     * 人员名称
     */
    private String name;

    /**
     * 身份证号
     */
    private String idCard;

    /**
     * 开户行
     */
    private String bankName;

    /**
     * 银行账号
     */
    private String bankCount;

    /**
     * 银行地址
     */
    private String bankAddress;

    /**
     * 实发
     */
    private BigDecimal actualMny;
    /**
     * 已发
     */
    private BigDecimal alreadyMny;
    /**
     * 剩余可发
     */
    private BigDecimal remainMny;



    /**
     * 创建时间
     */
    private String createTime;

    /**
     * 修改时间
     */
    private String updateTime;

    /**
     * 状态
     * 0-待支付、1-银行支付中、2-支付成功、3-支付失败
     * PM系统新增中间表数据时，设置初始状态为“待支付”
     */
    private String state;

    /**
     * PM单据id
     */
    private String pmBillId;

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getIdCard() {
        return idCard;
    }

    public void setIdCard(String idCard) {
        this.idCard = idCard;
    }

    public String getBankName() {
        return bankName;
    }

    public void setBankName(String bankName) {
        this.bankName = bankName;
    }

    public String getBankCount() {
        return bankCount;
    }

    public void setBankCount(String bankCount) {
        this.bankCount = bankCount;
    }

    public String getBankAddress() {
        return bankAddress;
    }

    public void setBankAddress(String bankAddress) {
        this.bankAddress = bankAddress;
    }

    public BigDecimal getActualMny() {
        return actualMny;
    }

    public void setActualMny(BigDecimal actualMny) {
        this.actualMny = actualMny;
    }

    public BigDecimal getAlreadyMny() {
        return alreadyMny;
    }

    public void setAlreadyMny(BigDecimal alreadyMny) {
        this.alreadyMny = alreadyMny;
    }

    public BigDecimal getRemainMny() {
        return remainMny;
    }

    public void setRemainMny(BigDecimal remainMny) {
        this.remainMny = remainMny;
    }

    public String getCreateTime() {
        return createTime;
    }

    public void setCreateTime(String createTime) {
        this.createTime = createTime;
    }

    public String getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(String updateTime) {
        this.updateTime = updateTime;
    }

    public String getState() {
        return state;
    }

    public void setState(String state) {
        this.state = state;
    }

    public String getPmBillId() {
        return pmBillId;
    }

    public void setPmBillId(String pmBillId) {
        this.pmBillId = pmBillId;
    }
}

==> zzyj-financeintegration-api-3.0.0-20250912.035831-124-sources.jar: com/ejianc/business/financeintegration/PMSalary/vo/PMGzDetailVO.java <==
package com.ejianc.business.financeintegration.PMSalary.vo;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;

import java.math.BigDecimal;


@TableName("PMSALARY_GZMX")
public class PMGzDetailVO {

    private static final long serialVersionUID = 1L;
    /**
     * 项目ID
     */
    private String id;

    /**
     * 人员名称
     */
    private String name;

    /**
     * 身份证号
     */
    private String idCard;

    /**
     * 开户行
     */
    private String bankName;

    /**
     * 银行账号
     */
    private String bankCount;

    /**
     * 银行地址
     */
    private String bankAddress;

    /**
     * 实发
     */
    private BigDecimal actualMny;
    /**
     * 已发
     */
    private BigDecimal alreadyMny;
    /**
     * 剩余可发
     */
    private BigDecimal remainMny;



    /**
     * 创建时间
     */
    private String createTime;

    /**
     * 修改时间
     */
    private String updateTime;

    /**
     * 状态
     * 0-待支付、1-银行支付中、2-支付成功、3-支付失败
     * PM系统新增中间表数据时，设置初始状态为“待支付”
     */
    private String state;

    /**
     * PM单据id
     */
    private String pmBillId;

    private String acName;
    private String acCode;
    private String yearMonth;
    private BigDecimal actualMnyAll;


    public String getAcName() {
        return acName;
    }

    public void setAcName(String acName) {
        this.acName = acName;
    }

    public String getAcCode() {
        return acCode;
    }

    public void setAcCode(String acCode) {
        this.acCode = acCode;
    }

    public String getYearMonth() {
        return yearMonth;
    }

    public void setYearMonth(String yearMonth) {
        this.yearMonth = yearMonth;
    }

    public BigDecimal getActualMnyAll() {
        return actualMnyAll;
    }

    public void setActualMnyAll(BigDecimal actualMnyAll) {
        this.actualMnyAll = actualMnyAll;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getIdCard() {
        return idCard;
    }

    public void setIdCard(String idCard) {
        this.idCard = idCard;
    }

    public String getBankName() {
        return bankName;
    }

    public void setBankName(String bankName) {
        this.bankName = bankName;
    }

    public String getBankCount() {
        return bankCount;
    }

    public void setBankCount(String bankCount) {
        this.bankCount = bankCount;
    }

    public String getBankAddress() {
        return bankAddress;
    }

    public void setBankAddress(String bankAddress) {
        this.bankAddress = bankAddress;
    }

    public BigDecimal getActualMny() {
        return actualMny;
    }

    public void setActualMny(BigDecimal actualMny) {
        this.actualMny = actualMny;
    }

    public BigDecimal getAlreadyMny() {
        return alreadyMny;
    }

    public void setAlreadyMny(BigDecimal alreadyMny) {
        this.alreadyMny = alreadyMny;
    }

    public BigDecimal getRemainMny() {
        return remainMny;
    }

    public void setRemainMny(BigDecimal remainMny) {
        this.remainMny = remainMny;
    }

    public String getCreateTime() {
        return createTime;
    }

    public void setCreateTime(String createTime) {
        this.createTime = createTime;
    }

    public String getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(String updateTime) {
        this.updateTime = updateTime;
    }

    public String getState() {
        return state;
    }

    public void setState(String state) {
        this.state = state;
    }

    public String getPmBillId() {
        return pmBillId;
    }

    public void setPmBillId(String pmBillId) {
        this.pmBillId = pmBillId;
    }
}
